@@ -82,16 +82,17 @@ resp_condition_fun1 <-
     }
     if_else2(
       ((DHHGAGE_cont > 0 & DHHGAGE_cont >= 35) &
-         (CCC_091 == 1 | CCC_031 == 1)), 1,
-      if_else2(
-        ((DHHGAGE_cont > 0 & DHHGAGE_cont < 35) &
-           (CCC_091 == 1)), 2,
-        if_else2(
-          ((DHHGAGE_cont > 0 & DHHGAGE_cont < 35) &
-             (CCC_091 == 2)), 3,
-          if_else2(
-            ((DHHGAGE_cont > 0 & DHHGAGE_cont >= 35) &
-              (CCC_091 == 2 & CCC_031 == 2)), 3, NA)
+        (CCC_091 == 1 | CCC_031 == 1)), 1,
+    if_else2(
+      ((DHHGAGE_cont > 0 & DHHGAGE_cont < 35) &
+        (CCC_031 == 1)), 2,
+    if_else2(
+      ((DHHGAGE_cont > 0 & DHHGAGE_cont < 35) &
+        (CCC_031 == 2)), 3,
+    if_else2(
+      ((DHHGAGE_cont > 0 & DHHGAGE_cont >= 35) &
+        (CCC_091 == 2 & CCC_031 == 2)), 3, "NA(b)"
+                )
           )
       )
     )
@@ -193,20 +194,20 @@ resp_condition_fun2 <-
 
     if_else2(
       ((DHHGAGE_cont > 0 & DHHGAGE_cont >= 35) &
-         (CCC_91E == 1 | CCC_91F == 1 | CCC_91A == 1 | CCC_031 == 1)), 1,
-      if_else2(
-        ((DHHGAGE_cont >= 30 & DHHGAGE_cont < 35) &
-           (CCC_91E == 1 | CCC_91F == 1 | CCC_91A == 1 | CCC_031 == 1)), 2,
-        if_else2(
-          ((DHHGAGE_cont > 0 & DHHGAGE_cont < 30) &
-             (CCC_91A == 1 | CCC_031 == 1)), 2,
-          if_else2(
-            ((DHHGAGE_cont > 0 & DHHGAGE_cont < 30) &
-               (CCC_91A == 2 & CCC_031 == 2)), 3,
-            if_else2(
-              ((DHHGAGE_cont > 0 & DHHGAGE_cont >= 30) &
-                 (CCC_91E == 2 & CCC_91F == 2 & CCC_91A == 2 &
-                        CCC_031 == 2)), 3, NA)
+        (CCC_91E == 1 | CCC_91F == 1 | CCC_91A == 1 | CCC_031 == 1)), 1,
+    if_else2(
+      ((DHHGAGE_cont >= 30 & DHHGAGE_cont < 35) &
+        (CCC_91E == 1 | CCC_91F == 1 | CCC_91A == 1 | CCC_031 == 1)), 2,
+    if_else2(
+      ((DHHGAGE_cont > 0 & DHHGAGE_cont < 30) &
+        (CCC_91A == 1 | CCC_031 == 1)), 2,
+    if_else2(
+      ((DHHGAGE_cont > 0 & DHHGAGE_cont < 30) &
+        (CCC_91A == 2 & CCC_031 == 2)), 3,
+    if_else2(
+      ((DHHGAGE_cont > 0 & DHHGAGE_cont >= 30) &
+        (CCC_91E == 2 & CCC_91F == 2 & CCC_91A == 2 & CCC_031 == 2)), 3,
+          "NA(b)")
           )
         )
       )
@@ -302,19 +303,19 @@ resp_condition_fun3 <-
 
     if_else2(
       ((DHHGAGE_cont > 0 & DHHGAGE_cont >= 35) &
-         (CCC_091 == 1 | CCC_91A == 1 | CCC_031 == 1)), 1,
-      if_else2(
-        ((DHHGAGE_cont >= 30 & DHHGAGE_cont < 35) &
-           (CCC_091 == 1 | CCC_91A == 1 | CCC_031 == 1)), 2,
-        if_else2(
-          ((DHHGAGE_cont > 0 & DHHGAGE_cont < 30) &
-             (CCC_91A == 1 | CCC_031 == 1)), 2,
-          if_else2(
-            ((DHHGAGE_cont > 0 & DHHGAGE_cont < 30) &
-               (CCC_91A == 2 & CCC_031 == 2)), 3,
-            if_else2(
-              ((DHHGAGE_cont > 0 & DHHGAGE_cont >= 30) & 
-                       (CCC_091 == 2 & CCC_91A == 2 & CCC_031 == 2)), 3, NA)
+        (CCC_091 == 1 | CCC_91A == 1 | CCC_031 == 1)), 1,
+    if_else2(
+      ((DHHGAGE_cont >= 30 & DHHGAGE_cont < 35) &
+        (CCC_091 == 1 | CCC_91A == 1 | CCC_031 == 1)), 2,
+    if_else2(
+      ((DHHGAGE_cont > 0 & DHHGAGE_cont < 30) &
+        (CCC_91A == 1 | CCC_031 == 1)), 2,
+    if_else2(
+      ((DHHGAGE_cont > 0 & DHHGAGE_cont < 30) &
+        (CCC_91A == 2 & CCC_031 == 2)), 3,
+    if_else2(
+      ((DHHGAGE_cont > 0 & DHHGAGE_cont >= 30) & 
+        (CCC_091 == 2 & CCC_91A == 2 & CCC_031 == 2)), 3, "NA(b)")
           )
         )
       )
