@@ -1,21 +1,21 @@
 test_that("adl_fun has expected output when ADL_01 is out of range",{
-  expect_equal(adl_fun(-1, 1, 1, 1, 1), NA)
+  expect_equal(adl_fun(-1, 1, 1, 1, 1), "NA(b)")
 })
 
 test_that("adl_fun has expected output when ADL_02 is out of range",{
-  expect_equal(adl_fun(1, -1, 1, 1, 1), NA)
+  expect_equal(adl_fun(1, -1, 1, 1, 1), "NA(b)")
 })
 
 test_that("adl_fun has expected output when ADL_03 is out of range",{
-  expect_equal(adl_fun(1, 1, -1, 1, 1), NA)
+  expect_equal(adl_fun(1, 1, -1, 1, 1), "NA(b)")
 })
 
 test_that("adl_fun has expected output when ADL_04 is out of range",{
-  expect_equal(adl_fun(1, 1, 1, -1, 1), NA)
+  expect_equal(adl_fun(1, 1, 1, -1, 1), "NA(b)")
 })
 
 test_that("adl_fun has expected output when ADL_05 is out of range",{
-  expect_equal(adl_fun(1, 1, 1, 1, -1), NA)
+  expect_equal(adl_fun(1, 1, 1, 1, -1), "NA(b)")
 })
 
 test_that("adl_fun has expected output when all values are in range",{
