@@ -1,13 +1,13 @@
 test_that("pack_years_fun() has expected outputs when
           SMKDSTY is out of range", {
   expect_equal(pack_years_fun(10, 40, 6, 6, 22, 96, 12, 996, 996, 96, 96, 1),
-               NA)
+               tagged_na("b"))
 })
 
 test_that("pack_years_fun() has expected outputs when
           DHHGAGE_cont is out of range", {
   expect_equal(pack_years_fun(1, -1, 6, 6, 22, 96, 12, 996, 996, 96, 96, 1),
-               NA)
+               tagged_na("b"))
 })
 
 test_that("pack_years_fun() has expected outputs when
